@@ -1,14 +1,11 @@
 from abc import ABC
 from abc import abstractmethod
-from dataclasses import is_dataclass
 from importlib import import_module
 from inspect import getmodule
 from logging import getLogger
 from pkgutil import walk_packages
 from typing import List
 
-from qq.types import CustomBaseType
-
 logger = getLogger(__name__)
 
 
@@ -85,13 +82,3 @@ class ObjectFinder(ABC):
     @abstractmethod
     def is_collectable(self, element: object):
         pass  # pragma: no cover
-
-
-class DataclassFinder(ObjectFinder):
-    def is_collectable(self, element: object):
-        return is_dataclass(element)
-
-
-class CustomBaseTypeFinder(ObjectFinder):
-    def is_collectable(self, element: object):
-        return issubclass(element, CustomBaseType)
