@@ -2,7 +2,7 @@ from os.path import dirname
 
 from qq.application import Application
 from qq.context import Context
-from qq.injector import Injector
+from qq.injectors import ContextInicjator
 from qq.plugin import Plugin
 
 TESTS_KEY = "tests"
@@ -12,27 +12,6 @@ def _import(modulepath):
     return __import__(modulepath, globals(), locals(), [""])
 
 
-class PrefixedStringsDict(dict):
-    def __init__(self, prefix="", module=None):
-        self.prefix = prefix
-        if module:
-            self.set_prefix_from_module(module)
-
-    def set_prefix(self, prefix):
-        self.prefix = prefix
-
-    def __getitem__(self, key):
-        return self.prefix + super().__getitem__(key)
-
-    def __setitem__(self, key, value):
-        if not isinstance(value, str):
-            raise ValueError("PrefixedStringsDict can be set only by strings!")
-        return super().__setitem__(key, value)
-
-    def set_prefix_from_module(self, module):
-        self.prefix = dirname(module.__file__)
-
-
 class SettingsPlugin(Plugin):
     """
     This class will generate settings for different startpoints. `modulepath`
@@ -64,6 +43,6 @@ class SettingsBasedPlugin(Plugin):
         return source.globals[SettingsPlugin.key][self.key]
 
 
-@Injector
-def SettingsInjector(context: Context, key: str):
-    return context[SettingsPlugin.key][key]
+class SettingsInicjator(ContextInicjator):
+    def start(self):
+        return self.context[SettingsPlugin.key][self.key]
