@@ -1,11 +1,11 @@
 from abc import ABC
 
 
-class CustomBaseType:
+class BaseInjector:
     pass
 
 
-class PluginKey(str, CustomBaseType):
+class PluginKey(str):
     pass
 
 
